@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 __author__ = 'Robert Ancell <bob27@users.sourceforge.net>, John-Paul Gignac  <jjgignac@users.sf.net>'
 __license__ = 'GNU General Public License Version 2+'
 __copyright__ = 'Copyright 2005-2006  Robert Ancell, Copyright 2006  John-Paul Gignac'
@@ -7,6 +8,7 @@ from OpenGL.GL import *
 from glchess.defaults import *
 import glchess.scene
 import texture
+import os.path
 
 WHITE_BASE      = (0.95, 0.81, 0.64)
 WHITE_AMBIENT   = (0.7*WHITE_BASE[0], 0.7*WHITE_BASE[1], 0.7*WHITE_BASE[2], 1.0)
@@ -24,9 +26,6 @@ BLACK_SHININESS = 64.0
 # NOTE: This will not work if rendered in different openGL contexts
 _displayLists = {}
 
-# HACK
-import os.path
-    
 # Vector methods
     
 def vectordiff(a, b):
@@ -150,7 +149,7 @@ class WhiteBuiltinSet(BuiltinSet):
     """
     
     def __init__(self):
-        BuiltinSet.__init__(self, os.path.join(IMAGE_DIR, 'piece.png'), WHITE_AMBIENT, WHITE_DIFFUSE, WHITE_SPECULAR, WHITE_SHININESS)
+        BuiltinSet.__init__(self, os.path.join(TEXTURE_DIR, 'piece.png'), WHITE_AMBIENT, WHITE_DIFFUSE, WHITE_SPECULAR, WHITE_SHININESS)
         self.setRotation(180.0)
         self.addState('unselected', (0.9, 0.9, 0.9), default = True)
 
@@ -159,7 +158,7 @@ class BlackBuiltinSet(BuiltinSet):
     """
     
     def __init__(self):
-        BuiltinSet.__init__(self, os.path.join(IMAGE_DIR, 'piece.png'), BLACK_AMBIENT, BLACK_DIFFUSE, BLACK_SPECULAR, BLACK_SHININESS)
+        BuiltinSet.__init__(self, os.path.join(TEXTURE_DIR, 'piece.png'), BLACK_AMBIENT, BLACK_DIFFUSE, BLACK_SPECULAR, BLACK_SHININESS)
         self.addState('unselected', (0.2, 0.2, 0.2), default = True)
 
 ENDOFDATA      = 65535
@@ -208,15 +207,23 @@ class SimpleModel:
         # Collect the vertex coordinates
         # FIXME: How does the scaling work?
         vertices = []
+        texcoords = []
         for v in self.__vertices( 11.0 * 0.3 / 8192):
-            vertices.append( v)
+            vertices.append(v)
+            texcoords.append(self.__getTextureCoord(v, 16.783)) # FIXME: Max height not calculated
 
         # Zero out the normals
         normals = [(0,0,0)] * len(vertices)
 
         # Add up all the face normals at each vertex
+        tris = []
+        quads = []
         for f in self.__faces():
             if len(f) == 3:
+                tris.append(f[0])
+                tris.append(f[1])
+                tris.append(f[2])
+
                 d1 = vectordiff(vertices[f[1]], vertices[f[0]])
                 d2 = vectordiff(vertices[f[2]], vertices[f[0]])
                 normal = normalize(crossprod(d1,d2))
@@ -224,6 +231,11 @@ class SimpleModel:
                 normals[f[1]] = vectoradd(normals[f[1]],normal)
                 normals[f[2]] = vectoradd(normals[f[2]],normal)
             else:
+                quads.append(f[0])
+                quads.append(f[1])
+                quads.append(f[2])
+                quads.append(f[3])
+
                 d1 = vectordiff(vertices[f[1]], vertices[f[0]])
                 d2 = vectordiff(vertices[f[3]], vertices[f[0]])
                 normal = normalize(crossprod(d1,d2))
@@ -244,25 +256,17 @@ class SimpleModel:
         # Normalize the vertex normals
         for i in xrange(len(normals)):
             normals[i] = normalize(normals[i])
+                
+        glEnableClientState(GL_VERTEX_ARRAY)
+        glEnableClientState(GL_NORMAL_ARRAY)
+        glEnableClientState(GL_TEXTURE_COORD_ARRAY)
 
-        # Now draw the faces
-        for f in self.__faces():
-            if len(f) == 3:
-                glBegin(GL_TRIANGLES)
-            elif len(f) == 4:
-                glBegin(GL_QUADS)
-            elif len(f) == 0:
-                continue
-            else:
-                assert(False)
+        glVertexPointer(3, GL_FLOAT, 0, vertices)
+        glNormalPointer(GL_FLOAT, 0, normals)
+        glTexCoordPointer(2, GL_FLOAT, 0, texcoords)
 
-            for v in f:
-                glNormal3fv(normals[v])
-                vertex = vertices[v]
-                glTexCoord2fv(self.__getTextureCoord(vertex, 16.783)) # FIXME: Max height not calculated
-                glVertex3fv(vertex)
-
-            glEnd()
+        glDrawElementsui(GL_TRIANGLES, tris)
+        glDrawElementsui(GL_QUADS, quads)
 
     def end(self):
         pass
