@@ -11,15 +11,13 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
-#ifdef HAVE_GNOME
-#include <libgnome/gnome-help.h>
-#endif /* HAVE_GNOME */
-
 #include <libgames-support/games-conf.h>
 #include <libgames-support/games-files.h>
 #include <libgames-support/games-gridframe.h>
+#include <libgames-support/games-help.h>
 #include <libgames-support/games-scores-dialog.h>
 #include <libgames-support/games-stock.h>
+#include <libgames-support/games-runtime.h>
 
 #include "same-gnome.h"
 
@@ -31,12 +29,6 @@
 #define DEFAULT_WINDOW_WIDTH 450
 #define DEFAULT_WINDOW_HEIGHT 350
 
-/* Define an alternative to ngettext if we don't have it. Of course it isn't
- * a proper substitute for ngettext, but it is the best we can do. */
-#ifndef HAVE_NGETTEXT
-#define ngettext(one,lots,n) gettext(lots)
-#endif
-
 /* A collection of widgets we need to reference repeatedly. */
 GtkWidget *application;
 GtkWidget *messagewidget;
@@ -132,8 +124,8 @@ about_cb (GtkWidget * widget)
 			 "documenters", documenters,
 			 "comments",
 			 _
-			 ("I want to play that game! You know, they all go whirly-round and you click on them and they vanish!"),
-			 "copyright", "Copyright \xc2\xa9 2007 Callum McKenzie",
+			 ("I want to play that game! You know, they all go whirly-round and you click on them and they vanish!\n\nSame GNOME is a part of GNOME Games."),
+			 "copyright", "Copyright \xc2\xa9 2008 Callum McKenzie",
                          "license", license,
                          "wrap-license", TRUE,
 			 "translator-credits", _("translator-credits"),
@@ -199,7 +191,8 @@ game_over_dialog (gint place)
 				       GAMES_SCORES_QUIT_BUTTON |
 				       GAMES_SCORES_NEW_GAME_BUTTON);
       message = g_strdup_printf ("<b>%s</b>\n\n%s", _("Congratulations!"),
-				 _("Your score has made the top ten."));
+				 place == 1 ? _("Your score is the best!") :
+                                 _("Your score has made the top ten."));
       games_scores_dialog_set_message (gooddialog, message);
       g_free (message);
 
@@ -282,6 +275,7 @@ theme_cb (void)
   GtkTreeSelection *selection;
   GtkListStore *list;
   GamesFileList *filelist;
+  char *themedir;
 
   if (dialog) {
     gtk_window_present (GTK_WINDOW (dialog));
@@ -316,10 +310,12 @@ theme_cb (void)
 
     current_theme_index = -1;
     theme_index_counter = 0;
-    filelist = games_file_list_new_images (THEMEDIR, localthemedir, NULL);
+    themedir = g_build_filename (games_runtime_get_directory (GAMES_RUNTIME_GAME_THEME_DIRECTORY), THEME_VERSION, NULL);
+    filelist = games_file_list_new_images (themedir, localthemedir, NULL);
     games_file_list_transform_basename (filelist);
     games_file_list_for_each (filelist, (GFunc) fill_list, list);
     g_object_unref (filelist);
+    g_free (themedir);
 
     listview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list));
     g_object_unref (list);
@@ -443,11 +439,7 @@ size_change_cb (GtkRadioAction * action, gpointer data)
 static void
 help_cb (void)
 {
-#ifdef HAVE_GNOME
-  gnome_help_display ("same-gnome.xml", NULL, NULL);
-#else
-#warning need to port help to gtk-only!
-#endif /* HAVE_GNOME */
+  games_help_display (application, "same-gnome", NULL);
 }
 
 /* FIXME: Will we ever want this ? */
